%% ---- TurbSim: CREATE TURBULENT WIND FILES ------------------------------
% Fermin Reinicke
% EHU/UPV - Energia Berriztagarrien Ingeniaritza

%% ---- Prepare TurbSim ---------------------------------------------------

% Set the main parameters
WrFMTFF = 'False';     % Output full-field time-series data in formatted (readable) form?
% Originally: True      if True, generates RootName.u, RootName.v, RootName.w
%                           switch: T/F
NumGrid = '21';        % Grid-point matrix dimension (the size of the matrix will be NumGrid*NumGrid)
TSTStep = '0.05';      % Time step [s]
UsableT = '650';       % Usable length of output time series [s] (program will add GridWidth/MeanHHWS seconds)
%                        **The same value will be assigned to the 'AnalysisTime' parameter
HubHt = '90';          % Hub height [m] (should be > 0.5*GridHeight)
%RefH = HubH;            % Height of the reference windspeed 
%                      ### Erne! Agian hobe da beste leku batean abatzaren altuera definitzea eta altuera horretan blokeatzea
GridS = '165';         % Grid height and width [m] (should be >= 2*(RotorRadius+ShaftLength))
TurbM = '"IECKAI"';    % Turbulence model
%                        "IECKAI" --> Kaimal
%                        "IECVKM" --> von Karman
%                        "GP_LLJ", "NWTCUP", "SMOOTH", "WF_UPW", "WF_07D", "WF_14D", "TIDAL" or "NONE"
IECstandard = '1';     % Number of IEC 61400-x standard
% Originally: '1'        x = 1, 2, or 3
%                        **The entire variable is '"x-ED3"', but 'x' is the only character to switch
IECturbc = '"B"';      % IEC turbulence characteristic
%                        "A", "B", "C" or the turbulence intensity in percent
WindPT = 'PL';        % Wind profile type
%                        "JET"
%                        "LOG" --> logarithmic
%                        "PL"  --> power law
%                        "H2L" --> Log law for TIDAL spectral model
%                        "IEC" --> PL on rotor disk, LOG elsewhere
%                        or "default"
URef = '9';            % Mean (total) wind speed at the reference height [m/s] (or "default" for JET wind profile)
PLExp = 'default';     % Power law exponent [-] (or "default") 
Z0 = 'default';        % Surface roughness length [m] (or 'default')

% Change the parameters in the TurbSim.inp input file: 'chTurbSim'
chTurbSim(WrFMTFF, NumGrid, TSTStep, UsableT, HubHt, GridS, TurbM, IECstandard, IECturbc, WindPT, URef, PLExp, Z0);

%% ---- Launch TurbSim from Matlab ----------------------------------------

system(['FASTinput\TURBSIM\TurbSim.exe ','FASTinput\TURBSIM\TurbSim.inp'])

%% ---- Move the TurbSim output files to 'wind' directory -----------------
oldPath = 'FASTinput\TURBSIM\';
newPath = 'FASTinput\5MW_Baseline\Wind\';
TT = [TurbM(2:(length(TurbM)-1)) '_IEC61400-' IECstandard IECturbc(2)];
WindName = [num2str(HubHt),'m_',num2str(URef),'mps_',num2str(UsableT),'s__',TT,'_',WindPT,'__01'];   % haize fitxategiarentzako izena
                                                                                                     % azken zenbakia alda daiteke
if exist([oldPath,'TurbSim.bts'], 'file')==2                                                                                                     
    movefile([oldPath 'TurbSim.bts'], [newPath WindName '.bts']);               % 'TurbSim.bts' haize-outputa 'wind' karpetara eraman
end
mkdir([newPath,WindName]);              % Gainerako haize-outputak txukun gordetzeko karpeta sortu, 'wind' barruan
copyfile([oldPath 'TurbSim.inp'], [newPath WindName '\' WindName '.inp']);      % 'TurbSim.inp' inputa 'wind' karpetara eraman (kopiatuz)
movefile([oldPath 'TurbSim.sum'], [newPath WindName '\' WindName '.sum']);      % 'TurbSim.sum' haize-outputa 'wind' karpetara eraman
if exist([oldPath 'TurbSim.wnd'], 'file')==2
    movefile([oldPath 'TurbSim.wnd'], [newPath WindName '\' WindName '.wnd']);  % 'TurbSim.wnd' haize-outputa 'wind' karpetara eraman
end
if exist([oldPath,'TurbSim.hh'], 'file')==2
    movefile([oldPath 'TurbSim.hh'], [newPath WindName '\' WindName '.hh']);    % 'TurbSim.hh' haize-outputa 'wind' karpetara eraman
end
if exist([oldPath,'TurbSim.u'], 'file')==2
    movefile([oldPath 'TurbSim.u'], [newPath WindName '\' WindName '.u']);      % 'TurbSim.u' haize-outputa 'wind' karpetara eraman
    movefile([oldPath 'TurbSim.v'], [newPath WindName '\' WindName '.v']);      % 'TurbSim.v' haize-outputa 'wind' karpetara eraman
    movefile([oldPath 'TurbSim.w'], [newPath WindName '\' WindName '.w']);      % 'TurbSim.w' haize-outputa 'wind' karpetara eraman
end