function chElastoDyn(BlPitch,RotSpeed,NacYaw)
%chElastoDyn - Change the main parameters in the ElastoDyn.dat input file for FAST_v8.16.00a-bjj wind turbine simulator
%
%   chElastoDyn(BlPitch,RotSpeed,NacYaw)
%
%Input parameters (must be of class 'char'):
%
%BlPitch    -   Initial pitch for both the 3 blades [degrees]
%RotSpeed   -   Initial or fixed rotor speed [rpm]
%NacYaw     -   Initial or fixed nacelle-yaw angle [degrees]

%% ---- Input guztiak 'char' motakoak direla baieztatu --------------------

if ischar(BlPitch)==0 || ischar(RotSpeed)==0 || ischar(NacYaw)==0
    error('Error in chElastoDyn: all input args. must be of class "char".')
else

%% ---- ElastoDyn.dat-eko EDUKIA ERAUZI -----------------------------------

    fid=fopen('FASTinput\5MW_Baseline\NRELOffshrBsline5MW_OC3Hywind_ElastoDyn.dat','r');     % 'r' --> permission to read
    C=textscan(fid,'%s','delimiter','\n');      % C modu "txukun" batean sortuko da; ElastoDyn.dat-eko parametro bakoitza
                                                % eta haren deskribapena errenkada bakarrean kopiatuko baita
    fclose(fid);
    % C aldagaia "cell" (slot edo gelaxka) bakarraz osatuta dago, baina slot horretan 60 x 1 zutabe-matrize bat dago, errenkada
    % bakoitza ElastoDyn.dat-eko lerro oso bat delarik. Orain, parametro esanguratsuenak aldatuko dira C-n:

% -------------------------------------------------------------------------
%% ---- PARAMETROAK ALDATU ------------------------------------------------
    
    % 30, 31 eta 32. lerroak: 'BlPitch(1)', 'BlPitch(2)' eta 'BlPitch(3)' aldagaiak
    C{1,1}{30,1}(1:14) = blanks(14);            % aldagaiaren izena baino lehenagoko 14 posizio guztiak zuri bihurtu
    C{1,1}{31,1}(1:14) = blanks(14);
    C{1,1}{32,1}(1:14) = blanks(14);
    C{1,1}{30,1}(1:length(BlPitch)) = BlPitch;
    C{1,1}{31,1}(1:length(BlPitch)) = BlPitch;
    C{1,1}{32,1}(1:length(BlPitch)) = BlPitch;
    
    % 35. lerroa: 'RotSpeed' aldagaia
    C{1,1}{35,1}(1:14) = blanks(14);            % aldagaiaren izena baino lehenagoko 14 posizio guztiak zuri bihurtu
    C{1,1}{35,1}(1:length(RotSpeed)) = RotSpeed;
    
    % 36. lerroa: 'NacYaw' aldagaia
    C{1,1}{36,1}(1:14) = blanks(14);            % aldagaiaren izena baino lehenagoko 14 posizio guztiak zuri bihurtu
    C{1,1}{36,1}(1:length(NacYaw)) = NacYaw;
    
% -------------------------------------------------------------------------
%% ---- ElastoDyn.dat BERRIDATZI ------------------------------------------

    % ElastoDyn-eko parametroentzako nahi ditugun balioak C-n daudenez, orain C-ko edukia ElastoDyn.dat-en berridatzi behar da:
    fid=fopen('FASTinput\5MW_Baseline\NRELOffshrBsline5MW_OC3Hywind_ElastoDyn.dat','w');     % 'w' --> permission to write (discard existing contents)
    for lii=1:length(C{1,1}) 
      fprintf(fid,'%s\n',C{1,1}{lii,1});    % C-ko edukia string moduan idatzi eta
                                            % matrizearen gelaxka bakoitza idazten bukatzean hurrengo lerrora pasatu
    end
    fclose(fid);
end
end