function chFst(TMax,DT,CompElast,CompInflow,CompAero,CompServo,CompHydro,CompSub,CompMooring,InputF,Linearize,NLinTimes,LinTimes,LinInputs,LinOutputs)
%chFst - Change the main parameters in the main input file ("...".fst) for FAST_v8.16.00a-bjj wind turbine simulator
%
%       chFst(TMax,DT,CompElast,CompInflow,CompAero,CompServo,CompHydro,CompSub,...
%             CompMooring,InputF,Linearize,NLinTimes,LinTimes,LinInputs,LinOutputs)
%
%Input parameters (must be of class 'char'):
%
%TMax           -   Total run time [s]
%DT             -   Recommended module time step [s]
%CompElast      -   Compute structural dynamics (switch)
%                   1: ElastoDyn
%                   2: ElastoDyn + BeamDyn for blades
%CompInflow     -   Compute inflow wind velocities (switch)
%                   0: still air
%                   1: InflowWind
%                   2: external from OpenFOAM
%CompAero       -   Compute aerodynamic loads (switch)
%                   0: None
%                   1: AeroDyn v14
%                   2: AeroDyn v15
%CompServo      -   Compute control and electrical-drive dynamics (switch)
%                   0: None
%                   1: ServoDyn
%CompHydro      -   Compute hydrodynamic loads (switch)
%                   0: None
%                   1: HydroDyn
%CompSub        -   Compute sub-structural dynamics (switch)
%                   0: None
%                   1: SubDyn
%CompMooring    -   Compute Mooring system (switch)
%                   0: None
%                   1: MAP++
%                   2: FEAMooring
%                   3: MoorDyn
%                   4: OrcaFlex
%InputF         -   Input files' names. It's a cell that includes:
%                   InputF{1}: EDFile, ElastoDyn input file name
%                   InputF{2}: BDBldFile, BeamDyn input file name (for all blades)
%                   InputF{3}: InflowFile, inflow wind input file name
%                   InputF{4}: AeroFile, aerodynamic input file name
%                   InputF{5}: ServoFile, control and electrical-drive input file name
%                   InputF{6}: HydroFile, hydrodinamic input file name
%                   InputF{7}: SubFile, sub-structural input file name
%                   InputF{8}: MooringFile, mooring system input file name
%                   InputF{9}: IceFile, ice input file name
%Linearize      -   Linearization analysis
%                   Flag: T/F
%NLinTimes      -   Number of times to linearize
%LinTimes       -   List of times at which to linearize [s]
%LinInputs      -   Inputs included in linearization (switch)
%                   0: none
%                   1: standard
%                   2: all module inputs (debug)
%LinOutputs     -   Outputs included in linearization (switch)
%                   0: none
%                   1: from OutList(s)
%                   2: all module inputs (debug)

%% ---- Input guztiak 'char' motakoak direla baieztatu --------------------

if ischar(TMax)==0 || ischar(DT)==0 || ischar(CompElast)==0 || ischar(CompInflow)==0 ||...
   ischar(CompAero)==0 || ischar(CompServo)==0 || ischar(CompHydro)==0 ||...
   ischar(CompSub)==0 || ischar(CompMooring)==0 || ischar(InputF{1})==0 || ischar(InputF{2})==0 ||...
   ischar(InputF{3})==0 || ischar(InputF{4})==0 || ischar(InputF{5})==0 || ischar(InputF{6})==0 ||...
   ischar(InputF{7})==0 || ischar(InputF{8})==0 ||  ischar(InputF{9})==0 || ischar(Linearize)==0 ||...
   ischar(NLinTimes)==0 || ischar(LinTimes)==0 ||  ischar(LinInputs)==0 || ischar(LinOutputs)==0
    error('Error in chFst: all input args. must be of class "char".')
else

%% ---- OC3_Hywind.fst-ko EDUKIA ERAUZI -----------------------------------
    
    fid=fopen('FASTinput\OC3_Hywind.fst','r');     % 'r' --> permission to read
    C=textscan(fid,'%s','delimiter','\n');      % C modu "txukun" batean sortuko da; OC3_Hywind.fst-ko parametro bakoitza
                                                % eta haren deskribapena errenkada bakarrean kopiatuko baita
    fclose(fid);
    % C aldagaia "cell" (slot edo gelaxka) bakarraz osatuta dago, baina slot horretan 60 x 1 zutabe-matrize bat dago, errenkada
    % bakoitza HyWind_Test.fst-ko lerro oso bat delarik. Orain, parametro esanguratsuenak aldatuko dira C-n:

% -------------------------------------------------------------------------    
%% ---- PARAMETROAK ALDATU ------------------------------------------------

    % 6. lerroa: 'TMax' aldagaia
    C{1,1}{6,1}(1:14) = blanks(14);             % aldagaiaren izena baino lehenagoko 14 posizio guztiak zuri bihurtu
    C{1,1}{6,1}(1:length(TMax)) = TMax;

    % 7. lerroa: 'DT' aldagaia
    C{1,1}{7,1}(1:14) = blanks(14);             % aldagaiaren izena baino lehenagoko 14 posizio guztiak zuri bihurtu
    C{1,1}{7,1}(1:length(DT)) = DT;

    % 13. lerroa: 'CompElast' aldagaia
    C{1,1}{13,1}(1) = CompElast;
    
    % 14. lerroa: 'CompInflow' aldagaia
    C{1,1}{14,1}(1) = CompInflow;
    
    % 15. lerroa: 'CompAero' aldagaia
    C{1,1}{15,1}(1) = CompAero;
    
    % 16. lerroa: 'CompServo' aldagaia
    C{1,1}{16,1}(1) = CompServo;
    
    % 17. lerroa: 'CompHydro' aldagaia
    C{1,1}{17,1}(1) = CompHydro;
    
    % 18. lerroa: 'CompSub' aldagaia
    C{1,1}{18,1}(1) = CompSub;
    
    % 19. lerroa: 'CompMooring' aldagaia
    C{1,1}{19,1}(1) = CompMooring;
    
    % 22. lerroa: 'EDFile' aldagaia
    C{1,1}{22,1}(1:62) = blanks(62);            % aldagaiaren izena baino lehenagoko 62 posizio guztiak zuri bihurtu
    C{1,1}{22,1}(1:length(InputF{1})) = InputF{1};
    
    % 23, 24 eta 25. lerroak: 'BDBldFile' aldagaia
    C{1,1}{23,1}(1:62) = blanks(62);            % aldagaiaren izena baino lehenagoko 62 posizio guztiak zuri bihurtu
    C{1,1}{24,1}(1:62) = blanks(62);
    C{1,1}{25,1}(1:62) = blanks(62);
    C{1,1}{23,1}(1:length(InputF{2})) = InputF{2};
    C{1,1}{24,1}(1:length(InputF{2})) = InputF{2};
    C{1,1}{25,1}(1:length(InputF{2})) = InputF{2};
    
    % 26. lerroa: 'InflowFile' aldagaia
    C{1,1}{26,1}(1:62) = blanks(62);            % aldagaiaren izena baino lehenagoko 62 posizio guztiak zuri bihurtu
    C{1,1}{26,1}(1:length(InputF{3})) = InputF{3};
    
    % 27. lerroa: 'AeroFile' aldagaia
    C{1,1}{27,1}(1:62) = blanks(62);            % aldagaiaren izena baino lehenagoko 62 posizio guztiak zuri bihurtu
    C{1,1}{27,1}(1:length(InputF{4})) = InputF{4};
    
    % 28. lerroa: 'ServoFile' aldagaia
    C{1,1}{28,1}(1:62) = blanks(62);            % aldagaiaren izena baino lehenagoko 62 posizio guztiak zuri bihurtu
    C{1,1}{28,1}(1:length(InputF{5})) = InputF{5};
    
    % 29. lerroa: 'HydroFile' aldagaia
    C{1,1}{29,1}(1:62) = blanks(62);            % aldagaiaren izena baino lehenagoko 62 posizio guztiak zuri bihurtu
    C{1,1}{29,1}(1:length(InputF{6})) = InputF{6};
    
    % 30. lerroa: 'SubFile' aldagaia
    C{1,1}{30,1}(1:62) = blanks(62);            % aldagaiaren izena baino lehenagoko 62 posizio guztiak zuri bihurtu
    C{1,1}{30,1}(1:length(InputF{7})) = InputF{7};
    
    % 31. lerroa: 'MooringFile' aldagaia
    C{1,1}{31,1}(1:62) = blanks(62);            % aldagaiaren izena baino lehenagoko 62 posizio guztiak zuri bihurtu
    C{1,1}{31,1}(1:length(InputF{8})) = InputF{8};
    
    % 32. lerroa: 'IceFile' aldagaia
    C{1,1}{32,1}(1:62) = blanks(62);            % aldagaiaren izena baino lehenagoko 62 posizio guztiak zuri bihurtu
    C{1,1}{32,1}(1:length(InputF{9})) = InputF{9};
    
    % 43. lerroa: 'Linearize' aldagaia
    C{1,1}{43,1}(1:14) = blanks(14);            % aldagaiaren izena baino lehenagoko 14 posizio guztiak zuri bihurtu
    C{1,1}{43,1}(1:length(Linearize)) = Linearize;
    
    % 44. lerroa: 'NLinTimes' aldagaia
    C{1,1}{44,1}(1) = NLinTimes;
    
    % 45. lerroa: 'LinTimes' aldagaia
    C{1,1}{45,1}(1:20) = blanks(20);            % aldagaiaren izena baino lehenagoko 20 posizio guztiak zuri bihurtu. 20, bai, honek gehiago behar du.
    C{1,1}{45,1}(1:length(LinTimes)) = LinTimes;
    
    % 46. lerroa: 'LinInputs' aldagaia
    C{1,1}{46,1}(1) = LinInputs;
    
    % 47. lerroa: 'LinOutputs' aldagaia
    C{1,1}{47,1}(1) = LinOutputs;

% -------------------------------------------------------------------------
%% ---- OC3_Hywind.fst BERRIDATZI -----------------------------------------

    % TurbSim-eko parametroentzako nahi ditugun balioak C-n daudenez, orain C-ko edukia OC3_Hywind.fst-n berridatzi behar da:
    fid=fopen('FASTinput\OC3_Hywind.fst','w');     % 'w' --> permission to write (discard existing contents)
    for lii=1:length(C{1,1}) 
        fprintf(fid,'%s\n',C{1,1}{lii,1});    % C-ko edukia string moduan idatzi eta
                                            % matrizearen gelaxka bakoitza idazten bukatzean hurrengo lerrora pasatu
    end
    fclose(fid);
end
end