function chHydroDyn(WtrDens,WtrDpth,WaveMod,WaveHs,WaveTp,WavePkShp,WaveDir,CurrMod,CurrSSV0)
%chHydroDyn - Change the main parameters in the HydroDyn.dat input file for FAST_v8.16.00a-bjj wind turbine simulator
%
%       chHydroDyn(WtrDens,WtrDpth,WaveMod,WaveHs,WaveTp,WavePkShp,WaveDir,CurrMod,CurrSSV0)
%
%Input parameters (must be of class 'char'):
%
%WtrDens    -   Water density [kg/m^3]
%WtrDpth    -   Water depth [m]
%WaveMod    -   Incident wave kinematics model (switch)
%               0: none=still water
%               1: regular (periodic)
%               1P#: regular with user-specified phase
%               2: JONSWAP/Pierson-Moskowitz spectrum (irregular)
%               3: White noise spectrum (irregular)
%               4: user-defined spectrum from routine UserWaveSpctrm (irregular)
%               5: Externally generated wave-elevation time series
%               6: Externally generated full wave-kinematics time series (option 6 is invalid for PotMod/=0)
%WaveHs     -   Significant wave height of incident waves [m] (used only when WaveMod=1, 2, or 3)
%WaveTp     -   Peak-spectral period of incident waves [s] (used only when WaveMod=1 or 2)
%WavePkShp  -   Peak-shape parameter of incident wave spectrum [-] or "DEFAULT" (used only when WaveMod=2; use 1.0 for Pierson-Moskowitz)
%WaveDir    -   Incident wave propagation heading direction [] (unused when WaveMod=0 or 6)
%CurrMod    -   Current profile model (switch)
%               0: none=no current
%               1: standard
%               2: user-defined from routine UserCurrent
%CurrSSV0   -   Sub-surface current velocity at still water level  [m/s] (used only when CurrMod=1)

%% ---- Input guztiak 'char' motakoak direla baieztatu --------------------

if ischar(WtrDens)==0 || ischar(WtrDpth)==0 || ischar(WaveMod)==0 || ischar(WaveHs)==0 ||...
   ischar(WaveTp)==0 || ischar(WavePkShp)==0 || ischar(WaveDir)==0 || ischar(CurrMod)==0 ||...
   ischar(CurrSSV0)==0
    error('Error in chHydroDyn: all input args. must be of class "char".')
else
    
%% ---- HydroDyn.dat-eko EDUKIA ERAUZI ------------------------------------

    fid=fopen('FASTinput\5MW_Baseline\NRELOffshrBsline5MW_OC3Hywind_HydroDyn.dat','r');     % 'r' --> permission to read
    C=textscan(fid,'%s','delimiter','\n');      % C modu "txukun" batean sortuko da; HydroDyn-eko parametro bakoitza
                                                % eta haren deskribapena errenkada bakarrean kopiatuko baita
    fclose(fid);

    % C aldagaia "cell" (slot edo gelaxka) bakarraz osatuta dago, baina slot horretan 149 x 1 zutabe-matrize bat dago, errenkada
    % bakoitza HydroDyn-eko lerro oso bat delarik. Orain, parametro esanguratsuenak aldatuko dira C-n:

% -------------------------------------------------------------------------
%% ---- PARAMETROAK ALDATU ------------------------------------------------

    % 5. lerroa: 'WtrDens' aldagaia
    C{1,1}{5,1}(1:17) = blanks(17);             % aldagaiaren izena baino lehenagoko 17 posizio guztiak zuri bihurtu
    C{1,1}{5,1}(1:length(WtrDens)) = WtrDens;

    % 6. lerroa: 'WtrDpth' aldagaia
    C{1,1}{6,1}(1:17) = blanks(17);             % aldagaiaren izena baino lehenagoko 17 posizio guztiak zuri bihurtu
    C{1,1}{6,1}(1:length(WtrDpth)) = WtrDpth;

    % 9. lerroa: 'WaveMod' aldagaia
    C{1,1}{9,1}(1) = WaveMod;

    % 13. lerroa: 'WaveHs' aldagaia
    C{1,1}{13,1}(1:17) = blanks(17);             % aldagaiaren izena baino lehenagoko 17 posizio guztiak zuri bihurtu
    C{1,1}{13,1}(1:length(WaveHs)) = WaveHs;

    % 14. lerroa: 'WaveTp' aldagaia
    C{1,1}{14,1}(1:17) = blanks(17);             % aldagaiaren izena baino lehenagoko 17 posizio guztiak zuri bihurtu
    C{1,1}{14,1}(1:length(WaveTp)) = WaveTp;

    % 15. lerroa: 'WavePkShp' aldagaia (GAMMA, only used when WaveMod=2, use 1.0 for Pierson-Moskowitz)
    C{1,1}{15,1}(1:17) = blanks(17);             % aldagaiaren izena baino lehenagoko 17 posizio guztiak zuri bihurtu
    C{1,1}{15,1}(1:length(WavePkShp)) = WavePkShp;

    % 18. lerroa: 'WaveDir' aldagaia (THETA)
    C{1,1}{18,1}(1:17) = blanks(17);             % aldagaiaren izena baino lehenagoko 17 posizio guztiak zuri bihurtu
    C{1,1}{18,1}(1:length(WaveDir)) = WaveDir;

    % 38. lerroa: 'CurrMod' aldagaia
    C{1,1}{38,1}(1) = CurrMod;

    % 39. lerroa: 'CurrSSV0' aldagaia
    C{1,1}{39,1}(1:17) = blanks(17);             % aldagaiaren izena baino lehenagoko 17 posizio guztiak zuri bihurtu
    C{1,1}{39,1}(1:length(CurrSSV0)) = CurrSSV0;

% -------------------------------------------------------------------------
%% ---- HydroDyn.dat berridatzi -------------------------------------------

    % HydroDyn-eko parametroentzako nahi ditugun balioak C-n daudenez, orain C-ko edukia HydroDyn-en berridatzi behar da:
    fid=fopen('FASTinput\5MW_Baseline\NRELOffshrBsline5MW_OC3Hywind_HydroDyn.dat','w');     % 'w' --> permission to write (discard existing contents)
    for lii=1:length(C{1,1}) 
        fprintf(fid,'%s\n',C{1,1}{lii,1});    % C-ko edukia string moduan idatzi eta
                                              % matrizearen gelaxka bakoitza idazten bukatzean hurrengo lerrora pasatu
    end
    fclose(fid);
end
end