function chInflowWind(WindType,HWindSpeed,RefHt,PLexp,Filename,RefLength,FilenameRoot)
%chInflowWind - Change the main parameters in the InflowWind.dat input file for FAST_v8.16.00a-bjj wind turbine simulator
%
%       chInflowWind(WindType,HWindSpeed,RefHt,PLexp,Filename,RefLength,FilenameRoot)
%
%Input parameters (must be of class 'char'):
%
%WindType   -   Switch for wind file type
%               1: steady
%               2: uniform
%               3: binary TurbSim FF
%               4: binary Bladed-style FF
%               5: HAWC format
%               6: User defined
%HWindSpeed -   Horizontal windspeed [m/s] (used only when WindType=1)
%RefHt      -   Reference height for horizontal wind speed [m] (used only when WindType=1 or 2)
%PLexp      -   Power law exponent (used only when WindType=1)
%Filename   -   Name of the wind file (used only when WindType=2 or 3)
%               if WindType=2: Filename of time series data for uniform wind field
%               if WindType=3: Name of the Full field wind file to use (.bts)
%RefLength  -   Reference length for linear horizontal and vertical sheer [-]
%               (used only when WindType=2)
%FilenameRoot   -   Rootname of the full-field wind file to use (.wnd, .sum)
%                   (used only when WindType=4)

%% ---- Input guztiak 'char' motakoak direla baieztatu --------------------

if ischar(WindType)==0 || ischar(HWindSpeed)==0 || ischar(RefHt)==0 || ischar(PLexp)==0 ||...
   ischar(Filename)==0 || ischar(RefLength)==0
    error('Error in chInflowWind: all input args. must be of class "char".')
else

%% ---- InflowWind.dat-eko EDUKIA ERAUZI ----------------------------------
    
    fid=fopen('FASTinput\5MW_Baseline\NRELOffshrBsline5MW_InflowWind.dat','r');     % 'r' --> permission to read
    C=textscan(fid,'%s','delimiter','\n');      % C modu "txukun" batean sortuko da; InflowWind.inp-eko parametro bakoitza
                                                % eta haren deskribapena errenkada bakarrean kopiatuko baita
    fclose(fid);
    % C aldagaia "cell" (slot edo gelaxka) bakarraz osatuta dago, baina slot horretan 60 x 1 zutabe-matrize bat dago, errenkada
    % bakoitza InflowWind.inp-eko lerro oso bat delarik. Orain, parametro esanguratsuenak aldatuko dira C-n:

% -------------------------------------------------------------------------   
%% ---- PARAMETROAK ALDATU ------------------------------------------------

    % 5. lerroa: 'WindType' aldagaia
    C{1,1}{5,1}(1) = WindType;

    % 12. lerroa: 'HWindSpeed' aldagaia
    C{1,1}{12,1}(1:14) = blanks(14);            % aldagaiaren izena baino lehenagoko 14 posizio guztiak zuri bihurtu
    C{1,1}{12,1}(1:length(HWindSpeed)) = HWindSpeed;

    % 13. eta 17. lerroak: 'RefHt' aldagaia. WindType = 1 eta 2 kasuetarako
    C{1,1}{13,1}(1:14) = blanks(14);            % aldagaiaren izena baino lehenagoko 14 posizio guztiak zuri bihurtu
    C{1,1}{17,1}(1:14) = blanks(14);
    C{1,1}{13,1}(1:length(RefHt)) = RefHt;
    C{1,1}{17,1}(1:length(RefHt)) = RefHt;
    
    % 14. lerroa: 'PLexp' aldagaia
    C{1,1}{14,1}(1:14) = blanks(14);            % aldagaiaren izena baino lehenagoko 14 posizio guztiak zuri bihurtu
    C{1,1}{14,1}(1:length(PLexp)) = PLexp;
    
    % 16. eta 20. lerroak: 'Filename' aldagaia. WindType = 2,3 kasuetarako
    C{1,1}{16,1}(1:70) = blanks(70);            % aldagaiaren izena baino lehenagoko 70 posizio guztiak zuri bihurtu
    C{1,1}{20,1}(1:70) = blanks(70);
    C{1,1}{16,1}(1:length(Filename)) = Filename;
    C{1,1}{20,1}(1:length(Filename)) = Filename;
    
    % 18. lerroa: 'RefLength' aldagaia
    C{1,1}{18,1}(1:14) = blanks(14);            % aldagaiaren izena baino lehenagoko 14 posizio guztiak zuri bihurtu
    C{1,1}{18,1}(1:length(RefLength)) = RefLength;
    
    % 22. lerroa: 'FilenameRoot' aldagaia. WindType = 4 kasurako
    C{1,1}{22,1}(1:70) = blanks(70);            % aldagaiaren izena baino lehenagoko 70 posizio guztiak zuri bihurtu
    C{1,1}{22,1}(1:length(FilenameRoot)) = FilenameRoot;

% -------------------------------------------------------------------------
%% ---- InflowWind.inp BERRIDATZI -----------------------------------------

    % InflowWind-eko parametroentzako nahi ditugun balioak C-n daudenez, orain C-ko edukia InflowWind.inp-en berridatzi behar da:
    fid=fopen('FASTinput\5MW_Baseline\NRELOffshrBsline5MW_InflowWind.dat','w');     % 'w' --> permission to write (discard existing contents)
    for lii=1:length(C{1,1}) 
        fprintf(fid,'%s\n',C{1,1}{lii,1});    % C-ko edukia string moduan idatzi eta
                                              % matrizearen gelaxka bakoitza idazten bukatzean hurrengo lerrora pasatu
    end
    fclose(fid);
end
end