function chTurbSim(WrFMTFF,NumGrid,TimeStep,UsableTime,HubHt,GridSize,TurbModel,IECstandard,IECturbc,WindProfileType,URef,PLExp,Z0)
%chTurbSim - Change the main parameters in the TurbSim.inp input file for TurbSim v1.06.00 wind file generator
%
%       chTurbSim(WrFMTFF,NumGrid,TimeStep,UsableTime,HubHt,GridSize,TurbModel,IECstandard,IECturbc,WindProfileType,URef,Z0)
%
%Input parameters (must be of class 'char'):
%
%WrFMTFF    -   Output full-field time-series data in formatted (readable) form?
%               (Generates RootName.u, RootName.v, RootName.w)
%               flag: T/F
%NumGrid    -   Grid-point matrix dimension (the size of the matrix will be NumGrid*NumGrid)
%TimeStep   -   Time step [s]
%UsableTime -   Usable length of output time series [s]
%               **The same value will be assigned to the 'AnalysisTime' parameter
%HubHt      -   Hub height, as well as height of the reference windspeed [m]
%               (should be > 0.5*GridHeight)
%GridSize   -   Grid height and width [m] (should be >= 2*(RotorRadius+ShaftLength))
%TurbModel  -   Turbulence model
%               "IECKAI": Kaimal
%               "IECVKM": von Karman
%               "GP_LLJ", "NWTCUP", "SMOOTH", "WF_UPW", "WF_07D", "WF_14D", "TIDAL" or "NONE"
%IECstandard  -   Number of IEC 61400-x standard (switch)
%                 x = 1, 2 or 3
%IECturbc   -   IEC turbulence characteristic
%               "A"
%               "B"
%               "C" or
%               the turbulence intensity in percent
%WindProfileType  -   Wind Profile Type (switch)
%                     "JET"
%                     "LOG" --> logarithmic
%                     "PL" --> power law
%                     "H2L" --> Log law for TIDAL spectral model
%                     "IEC" --> PL on rotor disk, LOG elsewhere
%                     or "default"
%URef       -   Mean (total) wind speed at the reference height [m/s]
%               (or "default" for JET wind profile)
%Z0         -   Surface roughness length [m] (or 'default')

%% ---- Input guztiak 'char' motakoak direla baieztatu --------------------

if ischar(WrFMTFF)==0 || ischar(NumGrid)==0 || ischar(TimeStep)==0 || ischar(UsableTime)==0 ||...
   ischar(HubHt)==0 || ischar(GridSize)==0 || ischar(TurbModel)==0 || ischar(IECstandard)==0 ||...
   ischar(IECturbc)==0 || ischar(WindProfileType)==0 || ischar(URef)==0 || ischar(Z0)==0
    error('Error in chTurbSim: all input args. must be of class "char".')
else

%% ---- TurbSim.inp-eko EDUKIA ERAUZI -------------------------------------
    
    fid=fopen('FASTinput\TURBSIM\Turbsim.inp','r');     % 'r' --> permission to read
    C=textscan(fid,'%s','delimiter','\n');      % C modu "txukun" batean sortuko da; TurbSim.inp-eko parametro bakoitza
                                                % eta haren deskribapena errenkada bakarrean kopiatuko baita
    fclose(fid);
    % C aldagaia "cell" (slot edo gelaxka) bakarraz osatuta dago, baina slot horretan 60 x 1 zutabe-matrize bat dago, errenkada
    % bakoitza TurbSim.inp-eko lerro oso bat delarik. Orain, parametro esanguratsuenak aldatuko dira C-n:

% -------------------------------------------------------------------------
%% ---- PARAMETROAK ALDATU ------------------------------------------------
    
    % 12. lerroa: 'WrFMTFF' aldagaia
    C{1,1}{12,1}(1:20) = blanks(20);            % aldagaiaren izena baino lehenagoko 20 posizio guztiak zuri bihurtu
    C{1,1}{12,1}(1:length(WrFMTFF)) = WrFMTFF;
    
    % 18 eta 19. lerroak: 'NumGrid_Z' eta 'NumGrid_Y' aldagaiak
    C{1,1}{18,1}(1:20) = blanks(20);            % aldagaiaren izena baino lehenagoko 20 posizio guztiak zuri bihurtu
    C{1,1}{19,1}(1:20) = blanks(20);
    C{1,1}{18,1}(1:length(NumGrid)) = NumGrid;
    C{1,1}{19,1}(1:length(NumGrid)) = NumGrid;
    
    % 20. lerroa: 'TimeStep' aldagaia
    C{1,1}{20,1}(1:20) = blanks(20);            % aldagaiaren izena baino lehenagoko 20 posizio guztiak zuri bihurtu
    C{1,1}{20,1}(1:length(TimeStep)) = TimeStep;
    
    % 21. eta 22. lerroak: 'AnalysisTime' eta 'UsableTime' aldagaiak
    C{1,1}{21,1}(1:20) = blanks(20);            % aldagaiaren izena baino lehenagoko 20 posizio guztiak zuri bihurtu
    C{1,1}{22,1}(1:20) = blanks(20);
    C{1,1}{21,1}(1:length(UsableTime)) = UsableTime;
    C{1,1}{22,1}(1:length(UsableTime)) = UsableTime;
    
    % 23. eta 36. lerroak: 'HubHt' eta 'RefHt' aldagaiak
    C{1,1}{23,1}(1:20) = blanks(20);            % aldagaiaren izena baino lehenagoko 20 posizio guztiak zuri bihurtu
    C{1,1}{36,1}(1:20) = blanks(20);
    C{1,1}{23,1}(1:length(HubHt)) = HubHt;
    C{1,1}{36,1}(1:length(HubHt)) = HubHt;
    
    % 24. eta 25. lerroak: 'GridHeight' eta 'GridWidth' aldagaiak
    C{1,1}{24,1}(1:20) = blanks(20);            % aldagaiaren izena baino lehenagoko 20 posizio guztiak zuri bihurtu
    C{1,1}{25,1}(1:20) = blanks(20);
    C{1,1}{24,1}(1:length(GridSize)) = GridSize;
    C{1,1}{25,1}(1:length(GridSize)) = GridSize;
    
    % 30. lerroa: 'TurbModel' aldagaia
    C{1,1}{30,1}(1:20) = blanks(20);            % aldagaiaren izena baino lehenagoko 20 posizio guztiak zuri bihurtu
    C{1,1}{30,1}(1:length(TurbModel)) = TurbModel;
    
    % 31. lerroa: 'IECstandard' aldagaia
    C{1,1}{31,1}(2) = IECstandard;
    
    % 32. lerroa: 'IECturbc' aldagaia
    C{1,1}{32,1}(1:20) = blanks(20);            % aldagaiaren izena baino lehenagoko 20 posizio guztiak zuri bihurtu
    C{1,1}{32,1}(1:length(IECturbc)) = IECturbc;
    
    % 35. lerroa: 'WindProfileType' aldagaia
    C{1,1}{35,1}(1:20) = blanks(20);            % aldagaiaren izena baino lehenagoko 20 posizio guztiak zuri bihurtu
    C{1,1}{35,1}(1:length(WindProfileType)) = WindProfileType;
    
    % 37. lerroa: 'URef' aldagaia
    C{1,1}{37,1}(1:20) = blanks(20);            % aldagaiaren izena baino lehenagoko 20 posizio guztiak zuri bihurtu
    C{1,1}{37,1}(1:length(URef)) = URef;
    
    % 39. lerroa: 'PLExp' aldagaia
    C{1,1}{39,1}(1:20) = blanks(20);            % aldagaiaren izena baino lehenagoko 20 posizio guztiak zuri bihurtu
    C{1,1}{39,1}(1:length(PLExp)) = PLExp;
    
    % 40. lerroa: 'Z0' aldagaia
    C{1,1}{40,1}(1:20) = blanks(20);            % aldagaiaren izena baino lehenagoko 20 posizio guztiak zuri bihurtu
    C{1,1}{40,1}(1:length(Z0)) = Z0;
    
% -------------------------------------------------------------------------
%% ---- TurbSim.inp BERRIDATZI --------------------------------------------
    
    % TurbSim-eko parametroentzako nahi ditugun balioak C-n daudenez, orain C-ko edukia TurbSim.inp-en berridatzi behar da:
    fid=fopen('FASTinput\TURBSIM\TurbSim.inp','w');     % 'w' --> permission to write (discard existing contents)
    for lii=1:length(C{1,1}) 
      fprintf(fid,'%s\n',C{1,1}{lii,1});    % C-ko edukia string moduan idatzi eta
                                            % matrizearen gelaxka bakoitza idazten bukatzean hurrengo lerrora pasatu
    end
    fclose(fid);
end
end